@@ -22,10 +22,11 @@ class ConfigCommon:
 class ConfigWorkRequirement:
     always_upload: bool = True
     args: List[str] = field(default_factory=list)
-    capture_taskoutput: bool = True
+    capture_taskoutput: bool = False
     completed_task_ttl: Optional[float] = None  # In minutes
     csv_files: Optional[List[str]] = None
     docker_env: Optional[Dict] = None
+    docker_options: Optional[List] = None
     docker_password: Optional[str] = None
     docker_username: Optional[str] = None
     env: Dict = field(default_factory=dict)
@@ -35,7 +36,6 @@ class ConfigWorkRequirement:
     finish_if_any_task_failed: bool = False
     flatten_input_paths: Optional[bool] = None
     flatten_upload_paths: Optional[bool] = None
-    fulfil_on_submit: bool = False
     inputs_optional: List[str] = field(default_factory=list)
     inputs_required: List[str] = field(default_factory=list)
     instance_types: Optional[List[str]] = None
